﻿using System;
using System.Web;
using System.IO;
using System.Text;

namespace SelfAspNetCs.Chap10
{
    public class SourceOutputHandler : IHttpHandler
    {
        /// <summary>
        /// Web を使用するには、Web の web.config ファイルでこの
        /// ハンドラーを設定し、IIS に登録する必要があります。詳細については、 
        /// 次のリンクを参照してください: http://go.microsoft.com/?linkid=8101007
        /// </summary>
        #region IHttpHandler Members

        public bool IsReusable
        {
            // Managed Handler が別の要求に再利用できない場合は、false を返します。
            // 要求ごとに保存された状態情報がある場合、通常、これは false になります。
            get { return true; }
        }

        public void ProcessRequest(HttpContext context)
        {
            String orgPath = context.Request.PhysicalPath;
            String file = Path.GetFileNameWithoutExtension(orgPath);
            String srcPath = Path.Combine(Path.GetDirectoryName(orgPath), file);
            using(var reader = new StreamReader(srcPath, Encoding.UTF8)) {
                HttpResponse Response = context.Response;
                Response.Write("<html>");
                Response.Write("<head><title>" + file + "</title></head>");
                Response.Write("<body>");
                Response.Write("<h1>" + file + "</h1>");
                Response.Write("<table border='0'>");
                int cnt = 1;
                while(reader.Peek() > -1) {
                    Response.Write("<tr>");
                    Response.Write("<th align='right'>" + cnt + "</th>");
                    String line = context.Server.HtmlEncode(reader.ReadLine());
                    Response.Write("<td>" + line.Replace(" ", "&nbsp;") + "</td></tr>");
                    cnt++;
                }
                Response.Write("</body>");
                Response.Write("</html>");
            }
        }

        #endregion
    }
}
